@@ -18,6 +18,7 @@ import sys
 from calculate.core.server.func import Action, Tasks
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.cl_template import TemplatesError
+from calculate.lib.utils.binhosts import BinhostError
 from calculate.lib.utils.files import FilesError
 from calculate.update.update import UpdateError
 from calculate.update.emerge_parser import EmergeError
@@ -54,7 +55,7 @@ class ClUpdateAction(Action):
     """
     # ошибки, которые отображаются без подробностей
     native_error = (FilesError, UpdateError,
-                    TemplatesError,
+                    TemplatesError, BinhostError,
                     GitError, EmergeError)
 
     successMessage = None
@@ -67,13 +68,14 @@ class ClUpdateAction(Action):
          'tasks': [
             {'name': 'premerge',
              'message': __("Calculating dependencies"),
-             'method': 'Update.premerge("-uDN","--with-bdeps=y","@world")',
-             'condition': lambda Get:Get('cl_update_sync_only_set') == 'off'
+             'method': 'Update.premerge("-uDN","@world")',
+             'condition': lambda Get: (
+                 Get('cl_update_sync_only_set') == 'off' and
+                 Get('cl_update_pretend_set') == 'on')
             }],
          },
-        {'name': 'premerge:update',
+        {'name': 'update',
          'condition': lambda Get:Get('cl_update_pretend_set') == 'off',
-         'depend': Tasks.result("premerge", eq='yes')
          },
         {'name': 'update_other',
          'condition': lambda Get: ( Get('cl_update_pretend_set') == 'off' and
@@ -82,26 +84,14 @@ class ClUpdateAction(Action):
         {'name': 'update:update_world',
          'group': __("Updating packages"),
          'tasks': [
-             {'name': 'update:update_world',
+             {'name': 'update_world',
               'message': __("Calculating dependencies"),
-              'method': 'Update.emerge("","-uDN","--with-bdeps=y","@world")',
+              'method': 'Update.emerge_ask(cl_update_pretend_set,'
+                        '"-uDN","@world")',
               }
-         ]
+         ],
+         'condition': lambda Get: Get('cl_update_sync_only_set') == 'off'
          },
-        {'name': 'update:update_python',
-         'group': __("Updating Python"),
-         'tasks': [
-             {'name': 'update:python_updater',
-              'message': __('Find & rebuild packages broken due '
-                            'to a Python upgrade'),
-              'method': 'Update.emergelike("python-updater")',
-              'condition': UpdateConditions.was_installed(
-                  'dev-lang/python$', EmergeMark.PythonUpdater),
-              'decoration': 'Update.update_task("%s")' %
-                            EmergeMark.PythonUpdater
-              },
-         ]
-        },
         {'name': 'update:update_perl',
          'group': __("Updating Perl"),
          'tasks': [
@@ -197,7 +187,7 @@ class ClUpdateAction(Action):
               'foreach': 'cl_update_sync_rep',
               'message':
                   __("Fallback syncing the {eachvar:capitalize} repository"),
-              'method': 'Update.syncRepositories(eachvar)',
+              'method': 'Update.syncRepositories(eachvar,True)',
               'condition': lambda Get: ("getbinpkg" in Get('cl_features') and
                         not Get('cl_update_binhost_data')[0])
              },
@@ -209,7 +199,7 @@ class ClUpdateAction(Action):
              },
              {'name': 'sync_reps',
               'foreach': 'cl_update_sync_rep',
-              'message': __("Syncing the {eachvar:capitalize} repository"),
+              'message': __("Checking {eachvar:capitalize} updates"),
               'method': 'Update.syncRepositories(eachvar)',
               'condition': lambda Get: Get('cl_update_sync_rep')
              },
@@ -271,10 +261,22 @@ class ClUpdateAction(Action):
              {'name': 'sync_reps:cleanpkg',
               'message': __("Removing obsolete distfiles and binary packages"),
               'method': 'Update.cleanpkg()',
-              'condition': (lambda Get: Get('cl_update_cleanpkg_set') == 'on' and
-                                        Get('cl_update_outdate_set') == 'on'),
+              'condition': (
+                  lambda Get: Get('cl_update_cleanpkg_set') == 'on' and
+                              Get('cl_update_outdate_set') == 'on'),
               'essential': False
              },
+             {'name': 'update_packages_cache',
+              'message': __("Update packages index"),
+              'method': 'Update.download_packages(cl_update_portage_binhost,'
+                        'cl_update_package_cache)',
+              'essential': False,
+              'condition': lambda Get: (
+                  "getbinpkg" in Get('cl_features') and
+                  Get('cl_update_package_cache') and (
+                      Get('cl_update_outdate_set') == 'on' or
+                      Get('cl_update_package_cache_set') == 'on'))
+              },
              # сообщение удачного завершения при обновлении репозиториев
              {'name': 'success_syncrep',
               'message': __("Synchronization finished"),
@@ -282,9 +284,9 @@ class ClUpdateAction(Action):
                                                          "sync_other_reps",
                                                          "emerge_metadata",
                                                          "eix_update")),
-             }
+              }
          ]
-        },
+         },
         {'name': 'reps_synchronization',
          'group': __("System configuration"),
          'tasks': [
@@ -292,19 +294,25 @@ class ClUpdateAction(Action):
              'message': __("Fixing the settings"),
              'method': 'Update.applyTemplates(install.cl_source,'
                        'cl_template_clt_set,True,None,False)',
-             'condition': lambda Get: Get('cl_templates_locate')
-            },
+             'condition': lambda Get: (Get('cl_templates_locate') and
+                                       (Get('cl_update_world') != "update" or
+                                        Get('cl_update_outdate_set') == 'on' or
+                                        Get('cl_update_force_fix_set') == 'on'))
+
+             },
             {'name': 'dispatch_conf',
              'message': __("Updating configuration files"),
-             'method':'Update.dispatchConf()',
+             'method': 'Update.dispatchConf()',
              'condition': lambda Get: (Get('cl_dispatch_conf') != 'skip' and
-                                       Get('cl_update_pretend_set') == 'off')
-            },
+                                       Get('cl_update_pretend_set') == 'off' and
+                                       (Get('cl_update_outdate_set') == 'on' or
+                                        Get('cl_update_force_fix_set') == 'on'))
+             },
             {'name': 'binhost_changed',
              'method': 'Update.message_binhost_changed()'
-            },
+             },
          ]
-        }
+         }
     ] + emerge_tasks + [
         {'name': 'failed',
          'error': __("Update failed"),
