@@ -18,6 +18,7 @@ import sys
 from calculate.core.server.func import Action, Tasks
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.cl_template import TemplatesError
+from calculate.lib.utils.binhosts import BinhostError
 from calculate.lib.utils.files import FilesError
 from calculate.update.update import UpdateError
 from calculate.lib.utils.git import GitError
@@ -33,7 +34,7 @@ class ClUpdateProfileAction(Action):
     """
     # ошибки, которые отображаются без подробностей
     native_error = (FilesError,
-                    TemplatesError,
+                    TemplatesError, BinhostError,
                     UpdateError, GitError)
 
     successMessage = __("The profile was successfully updated")
@@ -57,7 +58,7 @@ class ClUpdateProfileAction(Action):
          'depend': Tasks.has('migrate_repository')
          },
         {'name': 'check_datavars',
-         'error': _("Profile not found in master branch"),
+         'error': _("Profile not found in master"),
          'condition': lambda Get: not Get('update.cl_update_profile_datavars')
          },
         {'name': 'drop_binhosts',
